AudioBuffers

Struct AudioBuffers 

pub struct AudioBuffers {
    pub settings: AudioSettings,
    /* private fields */
}
Container for the input and output audio buffers

Use ProgramVector::audio to access the audio buffers

Fields

settings: AudioSettings

Current audio settings (set by the os / device)

Implementations

Source

impl AudioBuffers

pub fn run( &mut self, f: impl FnMut(&Buffer<Interleaved<&[i32]>>, &mut Buffer<Interleaved<&mut [i32]>>), ) -> !

Start processing audio samples

Supply a closure which will be run for each audio block as it is received. The closure will have access to an input and output buffer. The number of channels depends on self.settings.channels. The buffers are invalidated after each block, so must not escape the closure.

This function never terminates.

pub fn process( &mut self, f: impl FnMut(&Buffer<Interleaved<&[i32]>>, &mut Buffer<Interleaved<&mut [i32]>>), )

Process the next audio buffer