Struct ProgramVector

pub struct ProgramVector { /* private fields */ }
Shared object used to communicate with the host OS

You should not try to create it directly, use the #[patch] attribute macro instead.

Implementations

Source

impl ProgramVector

pub fn midi(&mut self) -> Midi

Get midi send/receive interface

pub fn screen(&mut self) -> Screen<'_>

Get screen

pub fn parameters(&self) -> Parameters

Get patch parameter controller

pub fn meta(&mut self) -> &mut Meta

Get patch metadata

pub fn audio(&mut self) -> &mut AudioBuffers

Get audio buffers

pub fn volts_per_sample(&mut self) -> (VoltsPerSample, VoltsPerSample)

Get calibrated volts per sample convertors as a pair (input, output)

let (vps_in, vps_out) = pv.volts_per_sample();
pub fn resources(&self) -> Resources<'_>

Get resources service

pub fn fft_real(&self, size: FftSize) -> Result<RealFft, &str>

Create a new Real FFT processor instance

pub fn fft_complex(&self, size: FftSize) -> Result<ComplexFft, &str>

Create a new Complex FFT processor instance