pub struct AudioBuffers {
pub settings: AudioSettings,
/* private fields */
}Expand description
Container for the input and output audio buffers
Use ProgramVector::audio to access the audio buffers
Fields
settings: AudioSettingsCurrent audio settings (set by the os / device)
Implementations
Sourceimpl AudioBuffers
impl AudioBuffers
Sourcepub fn run(
&mut self,
f: impl FnMut(&Buffer<Interleaved<&[i32]>>, &mut Buffer<Interleaved<&mut [i32]>>),
) -> !
pub fn run( &mut self, f: impl FnMut(&Buffer<Interleaved<&[i32]>>, &mut Buffer<Interleaved<&mut [i32]>>), ) -> !
Start processing audio samples
Supply a closure which will be run for each audio block as it is received. The closure will have access to an input and output buffer. The number of channels depends on self.settings.channels. The buffers are invalidated after each block, so must not escape the closure.
This function never terminates.
Sourcepub fn process(
&mut self,
f: impl FnMut(&Buffer<Interleaved<&[i32]>>, &mut Buffer<Interleaved<&mut [i32]>>),
)
pub fn process( &mut self, f: impl FnMut(&Buffer<Interleaved<&[i32]>>, &mut Buffer<Interleaved<&mut [i32]>>), )
Process the next audio buffer