pub struct ProgramVector { /* private fields */ }Expand description
Shared object used to communicate with the host OS
You should not try to create it directly, use the #[patch] attribute macro instead.
Implementations
Sourceimpl ProgramVector
impl ProgramVector
Sourcepub fn parameters(&self) -> Parameters
pub fn parameters(&self) -> Parameters
Get patch parameter controller
Sourcepub fn audio(&mut self) -> &mut AudioBuffers
pub fn audio(&mut self) -> &mut AudioBuffers
Get audio buffers
Sourcepub fn volts_per_sample(&mut self) -> (VoltsPerSample, VoltsPerSample)
pub fn volts_per_sample(&mut self) -> (VoltsPerSample, VoltsPerSample)
Get calibrated volts per sample convertors as a pair (input, output)
let (vps_in, vps_out) = pv.volts_per_sample();Sourcepub fn fft_real(&self, size: FftSize) -> Result<RealFft, &str>
pub fn fft_real(&self, size: FftSize) -> Result<RealFft, &str>
Create a new Real FFT processor instance
Sourcepub fn fft_complex(&self, size: FftSize) -> Result<ComplexFft, &str>
pub fn fft_complex(&self, size: FftSize) -> Result<ComplexFft, &str>
Create a new Complex FFT processor instance